==> open_web_calendar-1.38.dev29.tar.gz: open_web_calendar-1.38.dev29/docs/contributing.md <==
---
# SPDX-FileCopyrightText: 2024 Nicco Kunzmann and Open Web Calendar Contributors <https://open-web-calendar.quelltext.eu/>
#
# SPDX-License-Identifier: CC-BY-SA-4.0

comments: true
description: "You can improve the project yourself. Get started here."
---

# Contribute ♥️

[![Sponsor with GitHub](https://img.shields.io/github/sponsors/niccokunzmann?logo=github&label=GitHub%20Sponsors
)]({{link.fund.github_sponsors}})
[![Support on Open Collective](https://img.shields.io/opencollective/all/open-web-calendar?label=support%20on%20open%20collective)]({{link.fund.open_collective}})
[![Fund Issues with Polar](https://img.shields.io/github/issues/niccokunzmann/open-web-calendar?logo=github&label=issues%20seek%20funding&color=%230062ff)]({{link.fund.polar}})


There are several ways in which you can help this project:

- [Use it]({{link.web}}) and [report errors]({{link.issues}})
- [Donate using Open Collective]({{link.fund.open_collective}})
- [Fund specific issues with Polar]({{link.fund.polar}})
- [Donate using GitHub Sponsors]({{link.fund.github_sponsors}})
- [Translate this project](../dev/translate)
- Have a look at [open issues]({{link.issues}}) e.g. those especially to get started, labeled [good first issue]({{link.good_first_issue}}), leave a note and work on it.
- If you customized a calendar, please consider [contributing it as a template](../templates) for others to use.

If you are part of a company and you would like to commission work, please get in touch with Nicco Kunzmann.

==> open_web_calendar-1.42.tar.gz: open_web_calendar-1.42/docs/contributing.md <==
---
# SPDX-FileCopyrightText: 2024 Nicco Kunzmann and Open Web Calendar Contributors <https://open-web-calendar.quelltext.eu/>
#
# SPDX-License-Identifier: CC-BY-SA-4.0

comments: true
description: "You can improve the project yourself. Get started here."
---

# Contribute ♥️

[![Sponsor with GitHub](https://img.shields.io/github/sponsors/niccokunzmann?logo=github&label=GitHub%20Sponsors
)]({{link.fund.github_sponsors}})
[![Support on Open Collective](https://img.shields.io/opencollective/all/open-web-calendar?label=support%20on%20open%20collective)]({{link.fund.open_collective}})
[![Fund Issues with Polar](https://img.shields.io/github/issues/niccokunzmann/open-web-calendar?logo=github&label=issues%20seek%20funding&color=%230062ff)]({{link.fund.polar}})


There are several ways in which you can help this project:

- [Use it]({{link.web}}) and [report errors]({{link.issues}})
- [Fund development & maintenance - Polar]({{link.fund.polar}})
- [Fund costs - Open Collective]({{link.fund.open_collective}})
- [Fund sustainability - GitHub Sponsors]({{link.fund.github_sponsors}})
- [Translate this project to your language](../dev/translate)
- Have a look at [open issues]({{link.issues}}) e.g. those especially to get started, labeled [good first issue]({{link.good_first_issue}}), leave a note and work on it.
- If you customized a calendar, please consider [contributing it as a template](../templates) for others to use.

If you are part of a company depending on the Open Web Calendar,
please contact Nicco Kunzmann, the maintainer:

- You need features added.
- You want to mitigate risks.
- You need add-ons or integrations.

Support plans and maintenance contracts are available.
